==> as2-lib-5.1.4-sources.jar: com/helger/as2lib/util/http/IAS2HttpResponseHandler.java <==
/*
 * The FreeBSD Copyright
 * Copyright 1994-2008 The FreeBSD Project. All rights reserved.
 * Copyright (C) 2013-2025 Philip Helger philip[at]helger[dot]com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE FREEBSD PROJECT ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FREEBSD PROJECT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of the FreeBSD Project.
 */
package com.helger.as2lib.util.http;

import java.io.IOException;

import javax.annotation.Nonnegative;
import javax.annotation.Nonnull;
import javax.annotation.WillNotClose;

import com.helger.commons.http.HttpHeaderMap;
import com.helger.commons.io.IWriteToStream;

/**
 * Abstract HTTP response handler. This abstraction layer may be used to either
 * write to a socket directly or to e.g. send an HTTP response via a servlet.
 *
 * @author Philip Helger
 */
@FunctionalInterface
public interface IAS2HttpResponseHandler
{
  /**
   * Added an HTTP header to the response. This method must be called before any
   * output is written.
   *
   * @param nHttpResponseCode
   *        The HTTP response code. E.g. 200 for "HTTP OK". Must be &gt; 0.
   * @param aHeaders
   *        Headers to use. May not be <code>null</code>.
   * @param aData
   *        Data to send as response body. May not be <code>null</code> but may
   *        be empty.
   * @throws IOException
   *         In case of error
   */
  void sendHttpResponse (@Nonnegative int nHttpResponseCode,
                         @Nonnull HttpHeaderMap aHeaders,
                         @Nonnull @WillNotClose IWriteToStream aData) throws IOException;
}

==> as2-lib-5.1.7-sources.jar: com/helger/as2lib/util/http/IAS2HttpResponseHandler.java <==
/*
 * The FreeBSD Copyright
 * Copyright 1994-2008 The FreeBSD Project. All rights reserved.
 * Copyright (C) 2013-2025 Philip Helger philip[at]helger[dot]com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE FREEBSD PROJECT ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FREEBSD PROJECT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of the FreeBSD Project.
 */
package com.helger.as2lib.util.http;

import java.io.IOException;

import javax.annotation.Nonnegative;
import javax.annotation.Nonnull;
import javax.annotation.WillNotClose;

import com.helger.commons.http.HttpHeaderMap;
import com.helger.commons.io.IWriteToStream;

/**
 * Abstract HTTP response handler. This abstraction layer may be used to either write to a socket
 * directly or to e.g. send an HTTP response via a servlet.
 *
 * @author Philip Helger
 */
@FunctionalInterface
public interface IAS2HttpResponseHandler
{
  /**
   * Added an HTTP header to the response. This method must be called before any output is written.
   *
   * @param nHttpResponseCode
   *        The HTTP response code. E.g. 200 for "HTTP OK". Must be &gt; 0.
   * @param aHeaders
   *        Headers to use. May not be <code>null</code>.
   * @param aData
   *        Data to send as response body. May not be <code>null</code> but may be empty.
   * @throws IOException
   *         In case of error
   */
  void sendHttpResponse (@Nonnegative int nHttpResponseCode,
                         @Nonnull HttpHeaderMap aHeaders,
                         @Nonnull @WillNotClose IWriteToStream aData) throws IOException;
}
